import { createRouter, createWebHistory, RouterView } from "vue-router";
import Home from "../views/Home.vue";
import SearchPage from "../views/SearchPage.vue";
import ShowUnit from "../views/ShowUnit.vue";
import BookPage from "../views/BookPage.vue";
import Page from "../views/Page.vue";
import BookSuccess from "../views/BookSuccess.vue";
import Profile from "../views/Account/Profile.vue";
import NotFound from "../views/NotFound.vue";
import Error from "../views/Error.vue";
import Success from "../views/Success.vue";
import ServerError from "../views/ServerError.vue";
import Reservations from "../views/Account/Reservations.vue";
import Wallet from "../views/Wallet.vue";
import store from '../store';
// import verifyNumber from "../views/verifyNumber.vue";
import Login from "../views/Login.vue";
// import Register from "../views/Register.vue";
import Update from "../views/Update.vue";
import Points from "../views/Points.vue";

import {getActiveLanguage} from "laravel-vue-i18n";
import Account from "@/views/Account/Account.vue";
import SingleReservationPage from "@/views/Account/SingleReservationPage.vue";
import RedirectPage from '../views/Redirect.vue'

const routes = [
    {
        path: '/:lang?',
        component: RouterView,
        children: [
            {
                path: "",
                name: "Home",
                component: Home
            },
            {
                path: "login",
                name: "Login",
                component: Login
            },
            // {
            //     path: "register",
            //     name: "Register",
            //     component: Register
            // },
            {
                path: "units/:type?",
                name: "SearchPage",
                component: SearchPage
            },
            {
                path: "unit/:unit",
                name: "ShowUnit",
                component: ShowUnit
            },
            {
                path: "book",
                name: "BookPage",
                component: BookPage,
            },
            {
                path: "book/payment",
                name: "BookPayment",
                component: BookSuccess,
            },
            // {
            //     path: "account",
            //     name: "Profile",
            //     component: Profile,
            // },
            // {
            //     path: "reservations",
            //     name: "Reservations",
            //     component: Reservations
            // },
            // {
            //     path: "wallet",
            //     name: "wallet",
            //     component: Wallet
            // },
            {
                path: 'account',
                component: Account,
                children: [
                    {
                        path: "",
                        name: "profile",
                        component: Wallet
                    },
                    {
                        path: "bookings",
                        name: "bookings",
                        component: Reservations
                    },
                    {
                        path: "favourites",
                        name: "favourites",
                        component: Wallet
                    },
                    {
                        path: "wallet",
                        name: "wallet",
                        component: Wallet
                    },
                ]
            },
            {
                path: "bookings/:booking_id",
                name: "bookings.show",
                component: SingleReservationPage
            },
            {
                path: "redirect",
                name: "redirect",
                component: RedirectPage
            },
            // {
            //     path: "bookings/:booking_id/invoice",
            //     name: "invoice.show",
            //     component: SingleReservationPage
            // },
            // {
            //     path: "validate-number",
            //     name: "validate",
            //     component: verifyNumber
            // },
            // {
            //   path: "/404",
            //   name: "NotFound",
            //   component: NotFound,
            // },
            {
                path: "error",
                name: "Error",
                component: Error,
            },
            {
                path: "success",
                name: "Success",
                component: Success,
            },
            {
                path: "505",
                name: "ServerError",
                component: ServerError
            },
            {
                path: "update",
                name: "Update",
                component: Update
            },
            {
                path: "points",
                name: "Points",
                component: Points
            },
            {
                path: "page/:page",
                name: "page",
                component: Page
            },
            {
                path: ":pathMatch(.*)*",
                component: NotFound
            }
        ]
    }
];


let locale = window.location.pathname.replace(/^\/([^\/]+).*/i,'$1');

const router = createRouter({
    base: (locale.trim().length && locale !== "/") ? '/' + locale : undefined,
    scrollBehavior(to, from, savedPosition) {
        // always scroll to top
        return { top: 0 }
    },
  mode: 'history',
  history: createWebHistory(),
  routes,
});

router.beforeEach((to, from, next) => {
	const authPages = ['/reservations', '/validate-number'];
	const authRequired = authPages.includes(to.path);
	const loggedIn = store.state.CurrentUser.loggedIn;

    let language = getActiveLanguage();

    // if(!language){
    //     language = 'ar'
    // }

    // console.log(!to.fullPath.includes('ar') && !to.fullPath.includes('en'))
    // if (!to.fullPath.includes('ar') && !to.fullPath.includes('en')){
    //     fullPath = getActiveLanguage()+'/'+fullPath;
    //     next({
    //         path: language+to.fullPath,
    //         query: to.query
    //     });
    // }

    // next({
    //     path: '/ar/page/privacy-policy',
    //     query: to.query
    // });

    const { lang } = to.params;
    const redirectTo = lang ? to.fullPath : `${language}${to.fullPath}`;
    if (to.fullPath !== redirectTo) {

        // next({ path: redirectTo });
        // return;

    }else {
        next()
    }

    // if(!lang) {
    //     next({ path: to })
    // }
    // next()

	// trying to access a restricted page + not logged in
	// redirect to login page
	// if (authRequired && !loggedIn) {
	// 	next('/login');
	// } else {
	// 	next();
	// }
});

export default router;
