import axios from 'axios'

const state = {
	user: {
		email: '',
		password: ''
	},
	loggedIn: false,
	token: null
}
const getters = {
	get_loggedIn(state){
		return state.loggedIn;
	},
	userData(state){
		return state.user;
	},
	getUserToken(state){
		return state.token
	}
}
const actions = {
	getUser({commit}, user){
		return new Promise((resolve, reject) => {
			axios.post('/api/getUserData', user)
				.then(response => {
					commit('SET_user', JSON.stringify(response.data));
					commit("SET_loggedIn", true)
					resolve(response)

					// if (response.data.access_token){
					// 	localStorage.setItem('user_data', response.data.access_token)
					// }
				})
				.catch((error) => {
					commit("SET_user", '')
					commit("SET_token", '')
					commit("SET_loggedIn", false)

					reject(error.data)
				})
		})
	},
    checkOTP({commit}, payload) {
        return new Promise((resolve, reject) => {
            axios.post('/api/v1/user/check-otp', payload)
                .then(res => {

                    commit('SET_user', JSON.stringify(res.data.user));
                    commit("SET_token", res.data.access_token)

                    axios.defaults.headers.common['Authorization'] = "Bearer " + res.data.access_token;

                    if(res.data.user.name === null || res.data.user.email === null) {
                        document.body.classList.add('modal-open')
                        $('#registerDataPopupForm').modal('show')
                    }else {
                        commit("SET_loggedIn", true)
                    }

                    resolve(res)
                    // this.$toast.success('تم تفعيل رقم الجوال بنجاح');
                    // this.errors = null
                })
                .catch(errors => {
                    commit("SET_user", '')
                    commit("SET_token", '')
                    commit("SET_loggedIn", false)

                    reject(errors.data)
                })
        });
    },
    registerUser({commit}, payload) {
        return new Promise((resolve, reject) => {
            axios.post('/api/v1/user/register', payload)
                .then(res => {

                    commit('SET_user', JSON.stringify(res.data.user));
                    commit("SET_token", res.data.access_token)
                    commit("SET_loggedIn", true)

                    resolve(res)
                })
                .catch(errors => {
                    commit("SET_user", '')
                    commit("SET_token", '')
                    commit("SET_loggedIn", false)

                    reject(errors.data)
                })
        });
    },
    updateUser({commit}, user){
        axios.post(this.getAPILink('update'), user)
        .then(res => {
            this.$toast.success('تم تعديل الجساب بنجاح.');
            this.errors = null
        })
        .catch(errors => {

            code.forEach((element) => {
                element.value = ''
            });

            this.errors = errors.response.data.errors
            this.$toast.error('الكود غير صحيح.');
        })
    },
	refreshUser({commit}, user){
		return new Promise((resolve, reject) => {
			axios.post('/api/refresh', user)
				.then(response => {
					commit('SET_user', JSON.stringify(response.data.user_data));
					commit('SET_token', response.data.access_token);
					commit("SET_loggedIn", true)

					// if (response.data.access_token){
					// 	localStorage.setItem('user_data', response.data.access_token)
					// }
				})
				.catch((error) => {
					commit("SET_user", '')
					commit("SET_token", '')
					commit("SET_loggedIn", false)

					reject(error.data)
				})
		})
	},
	performLogin({commit}, payload){
		return new Promise((resolve, reject) => {
			axios.post("/api/v1/login", payload)
            .then((response) => {
                // commit('SET_user', JSON.stringify(response.data.user));
                // commit("SET_token", response.data.access_token)
                // commit("SET_loggedIn", true)

                // axios.defaults.headers.common['Authorization'] = "Bearer " + response.data.access_token;

                resolve(response)
            })
            .catch((error) => {
                reject(error.data)
            })
		})
	},
	performRegister({commit}, payload){
		return new Promise((resolve, reject) => {
			axios.post("/api/register", payload)
				.then((response) => {
					commit('SET_user', JSON.stringify(response.data.user));
					commit("SET_token", response.data.access_token)
					commit("SET_loggedIn", true)

					axios.defaults.headers.common['Authorization'] = "Bearer " + response.data.access_token;

					resolve(response.data)
				})
				.catch((error) => {
					reject(error.response.data.errors)
				})
		})
	},
	performLogout({commit, state}, payload){
		return new Promise((resolve, reject) => {
			axios.post("/api/logout", {}, {
				headers: {Authorization: `Bearer ${state.token}`}
			})
				.then((response) => {
					commit("SET_user", '')
					commit("SET_token", '')
					commit("SET_loggedIn", false)

					window.location.href = '/'
					resolve(response.data)
				})
				.catch((error) => {
					commit("SET_user", '')
					commit("SET_token", '')
					commit("SET_loggedIn", false)
					// reject(error.data)
				})
		})
	},
}
const mutations = {
	SET_user(state, payload){
		state.user = payload
	},
	SET_token(state, payload){
		state.token = payload
	},
	SET_loggedIn(state, payload){
		state.loggedIn = payload
	},
	SET_city(state, payload){
		state.city = payload
	}
}

export default {
	namespaced: true,
	actions,
	state,
	getters,
	mutations
}
