import axios from 'axios'

const state = {
	reservation: {
		'unit': '',
		'duration': '',
		'from': '',
		'to': '',
		'price': '',
		'total': '',
		'down_payment': '',
		'unit_image': '',
		'coupon': '',
		'discount': ''
	},
	final_reservation: {},
	res_data: {},
	res_unit_data: {},
	reservation_set: false
}

const getters = {
	get_reservation_data(state){
		return state.loggedIn;
	}
}

const actions = {
	performSetDataReservation({commit}, payload){
		return new Promise((resolve, reject) => {
			axios.post('/api/v1/get-reservation-details', payload)
				.then((res) => {
					commit('SET_res_unit_data', JSON.stringify(res.data))
					commit('SET_res_data', JSON.stringify(payload))
					commit('SET_reservation')
					resolve(res.data)
				})
				.catch((error) => {
					reject(error.data)
				})
		})
	},
	performUpdateReservation({commit}, payload){
		return new Promise((resolve, reject) => {
			axios.post('/api/check-coupon', payload)
			.then((res) => {
				commit('SET_discount_res_data', res.data)
				resolve(res.data)
			})
			.catch(function (error){
				commit('SET_discount_remove_res_data')
				reject(error.data)
			})
		});
	},
	performCancelCoupon({commit}, payload){
		return new Promise((resolve, reject) => {
			commit('SET_discount_remove_res_data')
			resolve(true)
		});
	},
	perFormNewReservation({commit}, payload){
		return new Promise((resolve, reject) => {
			axios.post('/api/v1/reservation-and-payment', payload)
            .then((res) => {
                commit('SET_res_unit_data', '')
                commit('SET_res_data', '')
                commit('SET_final_res_data', JSON.stringify(res.data))
                commit('SET_reservation', false)
                resolve(res.data)
            })
            .catch((error) => {
                reject(error.response.data.errors)
            })
		})
	}
}
const mutations = {
	SET_res_data(state, payload){
		state.res_data = payload
	},
	SET_res_unit_data(state, payload){
		state.res_unit_data = payload
	},
	SET_reservation(state){
		state.reservation_set = true
	},
	SET_final_res_data(state, payload){
		state.final_reservation = payload
	},
	SET_discount_res_data(state, payload){
		let res = JSON.parse(state.res_data)

		res.coupon = payload.coupon;
		res.discount = payload.discount;
		res.discount_currency = payload.discount_currency;
		res.discount_down_payment = payload.down_payment;
		res.discount_down_payment_currency = payload.down_payment_currency;
		res.after_discount = payload.after_discount;
		res.after_discount_currency = payload.after_discount_currency;

		state.res_data = JSON.stringify(res);
	},
	SET_discount_remove_res_data(state, payload){
		let res = JSON.parse(state.res_data)
		res.coupon = '';
		res.discount = '';
		res.discount_currency = '';
		res.discount_down_payment = '';
		res.discount_down_payment_currency = '';
		res.after_discount = '';
		res.after_discount_currency = '';

		state.res_data = JSON.stringify(res);
	}
}

export default {
	namespaced: true,
	actions,
	state,
	getters,
	mutations
}
